use cgmath::Point2;
use galactica_content::{Content, SystemHandle};
use galactica_galaxy::{Galaxy, GxShipHandle};
use galactica_systemsim::{ParticleBuilder, SystemSim};

/// Bundles parameters passed to a single call to GPUState::render
pub struct RenderState<'a> {
	/// Camera position, in world units
	pub camera_pos: Point2<f32>,

	/// Player ship data
	pub player_data: GxShipHandle,

	/// The system we're currently in
	pub current_system: SystemHandle,

	/// Height of screen, in world units
	pub camera_zoom: f32,

	/// The world state to render
	pub systemsim: &'a SystemSim,

	// TODO: handle overflow. is it a problem?
	/// The current time, in seconds
	pub current_time: f32,

	/// Game content
	pub content: &'a Content,

	/// Game data
	pub data: &'a Galaxy,

	/// Particles to spawn during this frame
	pub particles: &'a mut Vec<ParticleBuilder>,
}
